@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -39,7 +39,7 @@ class AdminFloatingIpAllocate(forms.SelfHandlingForm):
                                   required=False)
 
     def __init__(self, *args, **kwargs):
-        super(AdminFloatingIpAllocate, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         floating_pool_list = kwargs.get('initial', {}).get('pool_list', [])
         self.fields['pool'].choices = floating_pool_list
         tenant_list = kwargs.get('initial', {}).get('tenant_list', [])
