@@ -115,7 +115,7 @@ def data(TEST):
         {'id': "21023e92-8008-1234-8059-7f2293ff3889",
          'status': 'in-use',
          'size': 10,
-         'name': u'my_volume',
+         'name': 'my_volume',
          'display_description': '',
          'created_at': '2013-04-01 10:30:00',
          'volume_type': None,
@@ -129,7 +129,7 @@ def data(TEST):
          'name': 'my_volume2',
          'status': 'in-use',
          'size': 10,
-         'name': u'my_volume2',
+         'name': 'my_volume2',
          'display_description': '',
          'created_at': '2013-04-01 10:30:00',
          'volume_type': 'vol_type_2',
@@ -142,7 +142,7 @@ def data(TEST):
         {'id': "21023e92-8008-1234-8059-7f2293ff3890",
          'status': 'in-use',
          'size': 10,
-         'name': u'my_volume',
+         'name': 'my_volume',
          'display_description': '',
          'created_at': '2013-04-01 10:30:00',
          'volume_type': None,
@@ -164,26 +164,26 @@ def data(TEST):
 
     vol_type1 = volume_types.VolumeType(
         volume_types.VolumeTypeManager(None),
-        {'id': u'1',
-         'name': u'vol_type_1',
+        {'id': '1',
+         'name': 'vol_type_1',
          'description': 'type 1 description',
          'extra_specs': {'foo': 'bar',
                          'volume_backend_name': 'backend_1'}})
     vol_type2 = volume_types.VolumeType(
         volume_types.VolumeTypeManager(None),
-        {'id': u'2',
-         'name': u'vol_type_2',
+        {'id': '2',
+         'name': 'vol_type_2',
          'description': 'type 2 description'})
     vol_type3 = volume_types.VolumeType(
         volume_types.VolumeTypeManager(None),
-        {'id': u'3',
-         'name': u'vol_type_3',
+        {'id': '3',
+         'name': 'vol_type_3',
          'is_public': False,
          'description': 'type 3 description'})
     TEST.cinder_volume_types.add(vol_type1, vol_type2, vol_type3)
     vol_type_access1 = volume_type_access.VolumeTypeAccess(
         volume_type_access.VolumeTypeAccessManager(None),
-        {'volume_type_id': u'1', 'project_id': u'1'})
+        {'volume_type_id': '1', 'project_id': '1'})
     TEST.cinder_type_access.add(vol_type_access1)
 
     # Volumes - Cinder v2
@@ -253,14 +253,14 @@ def data(TEST):
     # Volume Type Encryption
     vol_enc_type1 = vol_enc_types.VolumeEncryptionType(
         vol_enc_types.VolumeEncryptionTypeManager(None),
-        {'volume_type_id': u'1',
+        {'volume_type_id': '1',
          'control_location': "front-end",
          'key_size': 512,
          'provider': "a-provider",
          'cipher': "a-cipher"})
     vol_enc_type2 = vol_enc_types.VolumeEncryptionType(
         vol_enc_types.VolumeEncryptionTypeManager(None),
-        {'volume_type_id': u'2',
+        {'volume_type_id': '2',
          'control_location': "front-end",
          'key_size': 256,
          'provider': "a-provider",
@@ -559,9 +559,9 @@ def data(TEST):
          'id': '2d2bb0d7-af28-4566-9a65-6d987c19093c',
          'resource_type': 'VOLUME',
          'resource_uuid': '6d53d143-e10f-440a-a65f-16a6b6d068f7',
+         'message_level': 'ERROR',
          'user_message': 'schedule allocate volume:An unknown error occurred.'
          })
-
     messages_2 = messages.Message(
         messages.MessageManager(None),
         {'created_at': '2020-07-12T12:56:43.000000',
@@ -570,6 +570,20 @@ def data(TEST):
          'id': 'd360b4e2-bda5-4289-b673-714a90cde80b',
          'resource_type': 'VOLUME_SNAPSHOT',
          'resource_uuid': '761634b0-fa1c-4e59-b8ad-d720807cb355',
+         'message_level': 'ERROR',
          'user_message': 'create snapshot:Snapshot is busy.'})
+    messages_3 = messages.Message(
+        messages.MessageManager(None),
+        {'created_at': '2020-09-24T11:03:31.000000',
+         'event_id': 'VOLUME_VOLUME_001_003',
+         'guaranteed_until': '2020-10-24T11:03:31.000000',
+         'id': '1f481885-9e1b-4d67-bdb5-b9db461391d3',
+         'resource_type': 'VOLUME',
+         'resource_uuid': 'f227c02d-91d7-4c3f-90d8-d8f261d0331a',
+         'message_level': 'ERROR',
+         'user_message': ('schedule allocate volume:'
+                          'Could not find any available weighted backend.'),
+         })
     TEST.cinder_messages.add(api.cinder.Message(messages_1))
     TEST.cinder_messages.add(api.cinder.Message(messages_2))
+    TEST.cinder_messages.add(api.cinder.Message(messages_3))
